#include <fork.h> /*always required in Fork programs*/
#include <io.h>       /*we use the printf() routine */ 

sh simple_lock screen = 0;

void main(void)
{
 start {
  initTracing( 10000 );
  startTracing();
  farm {
   join( 100; __NUM_PR__>=1; __RANK__<2)
     farm pprintf("JOIN-BODY! $=%d\n",$);
   else {
     pprintf("ELSE-PART!\n"); 
     continue;  /* go back to join head */
                /* break would leave it */
   }
  }
  stopTracing();
  writeTraceFile("JOINTEST", "test of join statement" );
 }
}

